﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Web;
using Contrib.SmsUslugi.Models;
using Orchard.ContentManagement;
using Orchard.ContentManagement.Handlers;
using Orchard.Data;
using Orchard.Localization;
using Orchard.Logging;
using Orchard.Security;

namespace Contrib.SmsUslugi.Handlers
{
    public class SmsuslugiSettingsPartHandler : ContentHandler
    {
        private readonly IEncryptionService encryptionService;

        public new ILogger Logger { get; set; }
        public Localizer T { get; set; }
        public SmsuslugiSettingsPartHandler(IRepository<SmsuslugiSettingsPartRecord> repository, IEncryptionService encryptionService)
        {
            T = NullLocalizer.Instance;
            Logger = NullLogger.Instance;

            this.encryptionService = encryptionService;
            Filters.Add(new ActivatingFilter<SmsuslugiSettingsPart>("Site"));
            Filters.Add(StorageFilter.For(repository));

            OnLoaded<SmsuslugiSettingsPart>(LazyLoadHandlers);
        }
        void LazyLoadHandlers(LoadContentContext context, SmsuslugiSettingsPart part)
        {
            part.AuthTokenField.Getter(() =>
            {
                try
                {
                    return String.IsNullOrWhiteSpace(part.Record.Password) ? String.Empty : Encoding.UTF8.GetString(encryptionService.Decode(Convert.FromBase64String(part.Record.Password)));
                }
                catch
                {
                    Logger.Error("The auth token could not be decrypted. It might be corrupted, try to reset it.");
                    return null;
                }
            });

            part.AuthTokenField.Setter(value => part.Record.Password = String.IsNullOrWhiteSpace(value) ? String.Empty : Convert.ToBase64String(encryptionService.Encode(Encoding.UTF8.GetBytes(value))));
        }
        protected override void GetItemMetadata(GetContentItemMetadataContext context)
        {
            if (context.ContentItem.ContentType != "Site")
                return;
            base.GetItemMetadata(context);
            context.Metadata.EditorGroupInfo.Add(new GroupInfo(T("sms")));
        }
    }
}