﻿using System;
using System.Collections.Generic;
using System.Linq;
using Contrib.SmsUslugi.Models;
using Orchard;
using Orchard.ContentManagement;
using Orchard.Localization;
using Orchard.Logging;
using Orchard.Messaging.Models;
using Orchard.Messaging.Services; 

namespace Contrib.SmsUslugi.Service
{
    public class SmsMessagingChannel : IMessagingChannel
    {
        private readonly IOrchardServices _orchardServices; 
        public const string SmsService = "sms";

        public ILogger Logger { get; set; }
        public Localizer T { get; set; }

        public SmsMessagingChannel(IOrchardServices orchardServices)
        {
            this._orchardServices = orchardServices;
            Logger = NullLogger.Instance;
        }

        public void SendMessage(MessageContext context)
        {
            if (!context.Service.Equals(SmsService, StringComparison.InvariantCultureIgnoreCase))
                return;

            var smsuslugiSettings = _orchardServices.WorkContext.CurrentSite.As<SmsuslugiSettingsPart>();

            // can't process sms's if the sms-uslugi settings have not yet been set
            if (smsuslugiSettings == null || !smsuslugiSettings.IsValid())
            {
                return;
            }

            if (context.Addresses.Count() == 0)
            {
                Logger.Error("Recipient is missing a mobile number");
                return;
            }
              
            SenderSms senderSms = new SenderSms(smsuslugiSettings.Login, smsuslugiSettings.Password, smsuslugiSettings.SenderTag, context.MailMessage.Body, null);
            foreach (var number in context.Addresses)
            {
                try
                {
                    senderSms.addNumber(number);
                    Logger.Debug("Message sent to {0}: {1}", number, context.Type);
                }
                catch (Exception e)
                {
                    Logger.Error(e, "An unexpected error while sending a message to {0}: {1}", number, context.Type);
                }
            }
            senderSms.SendSms();  
        }

        public IEnumerable<string> GetAvailableServices()
        {
            return new[] { SmsService };
        } 
    }
}